
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: src/ai/backend/helpers:dist

from setuptools import setup

setup(**{
    'author': 'Lablup Inc. and contributors',
    'classifiers': [
        'Intended Audience :: Developers',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Environment :: No Input/Output (Daemon)',
        'Topic :: Scientific/Engineering',
        'Topic :: Software Development',
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 3.11',
        'License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)',
    ],
    'description': 'Backend.AI Kernel Runner Prebuilt Binaries Package',
    'install_requires': (
        'types-setuptools',
    ),
    'license': 'LGPLv3',
    'long_description': """# Backend.AI In-kernel Helper Package
""",
    'long_description_content_type': 'text/markdown',
    'name': 'backend.ai-kernel-helper',
    'namespace_packages': (
    ),
    'package_data': {
        'ai.backend.helpers': (
            'VERSION',
        ),
    },
    'packages': (
        'ai.backend.helpers',
    ),
    'project_urls': {
        'Documentation': 'https://docs.backend.ai/',
        'Source': 'https://github.com/lablup/backend.ai',
    },
    'python_requires': '>=3.11,<3.12',
    'url': 'https://github.com/lablup/backend.ai',
    'version': """23.09.0a2
""",
    'zip_safe': False,
})
